{% extends "admin.html" %}

{% block body %}
    <div class="padding-md">
        <h1>Videos</h1>

        <div class="row">
            {% for video in videos %}
                <div class="col-md-6">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <i class="fa fa-desktop fa-fw"></i> {{ video.snippet.title }}
                        </div>
                        <div class="panel-body">
                            <iframe width="100%" height="360" src="https://www.youtube.com/embed/{{ video.id }}" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
                        </div>
                    </div>
                </div>
            {% endfor %}
        </div>
    </div>
{% endblock %}

