{% if component.as_pdf %}{% else %}
<div class="panel panel-default">
    {% if component.title %}
        <div class="panel-heading clearfix">
            <span class="pull-left">
                {% if component.icon %}<i class="fa {{ component.icon }}"></i>{% endif %} {{ component.title }}
            </span>
        </div>
    {% endif %}
    <div class="panel-body no-padding">
        <div class="padding-md">
            {{ component.text|safe }}
        </div>
    </div>
</div>
{% endif %}