# Generated by Django 2.1.1 on 2019-03-14 10:52

from django.db import migrations
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0011_auto_20190312_1716'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='token',
            field=djangoplus.db.models.fields.CharField(max_length=255, null=True, verbose_name='Token'),
        ),
    ]
