/* Whale Theme */

body {
    background-color: #fafaff;
    background: #70e1f5;  /* fallback for old browsers */
    background: -webkit-linear-gradient(to bottom, #ffd194, #70e1f5);  /* Chrome 10-25, Safari 5.1-6 */
    background: linear-gradient(to bottom, #fafaff, #0a507b); /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */

    color: #30343F;
}
a,
a:active,
.btn-default,
.fc .fc-button-group > button:active,
.fc .fc-button-group > button:focus,
.fc .fc-button-group > button:hover,
aside .nav > li > a,
aside .nav > li > a .fa,
aside .nav > li > a:hover .fa,
aside .nav > li > a.active .fa,
.navbar-top-links li a:active,
.navbar-top-links li a:focus,
.navbar-top-links .dropdown-menu li a:hover .fa,
.pagination > li > a,
.pagination > li > span {
    color: #0a507b;
}
a:hover {
    color: #666;
}
h2 .fa {
    color: #556f7a;
    font-size: 80%;
    margin-right: 5px;
    vertical-align: 0;
}
header.navbar,
#user-drop-down,
.breadcrumb,
.copyright,
.navbar-top-links .dropdown-alerts,
.paginator.paginator-admin,
.panel,
.sidebar {
    background-color: #fff;
    border: 0 none;
    border-radius: 4px;
}
header.navbar {
    margin: 20px;
    position: static;
}
#content {
    padding-top: 0;
}
#page-wrapper {
    background-color: transparent;
    border: 0 none;
    margin-top: 20px;
}
.action-links > a {
    margin: 0 2px;
}
.badge {
    background-color: #5a6169;
}
.breadcrumb {
    font-size: 90%;
    margin: 0 30px 30px;
    padding: 10px 20px;
}
.btn-default,
.fc .fc-today-button {
    background-color: rgba(10, 80, 123, 0.1);
    border: 0 none;
    border-radius: 4px;
}
.btn-default:hover,
.fc .fc-today-button:hover {
    background-color: rgba(10, 80, 123, 0.3);
    color: #0a507b;
}
.cards-container {
    margin-left: -10px;
    margin-right: -10px;
}
.card-panel {
    background-color: #fff;
    border: 0 none;
    border-radius: 4px;
    margin: 0 10px 20px;
    padding: 0;
}
.card-panel-item {
    border: 0 none;
    padding: 20px;
}
.card-panel-item .title {
    margin-top: 0;
}
.copyright {
    color: #556F7A;
    font-size: 80%;
    margin: 0 20px 10px;
    padding: 10px 20px;
}
.dashboard-aside,
.dashboard-header,
.dashboard-main,
.dashboard-footer {
    margin-left: 20px;
    margin-right: 20px;
}
.dashboard-aside.dashboard-aside-2 .panel {
    background-color: rgba(10, 80, 123, 0.75);
    color: #fff;
}
.dashboard-aside.dashboard-aside-2 .panel a {
    color: #fff;
}
.dashboard-aside.dashboard-aside-2 .panel.panel-default .panel-heading {
    border-color: rgba(10, 80, 123, 0.5);
    color: #fff;
}
.dashboard-aside.dashboard-aside-2 .panel.panel-default .panel-heading .fa {
    background-color: rgba(255, 255, 255, 0.25);
}
.fc .fc-center h2 {
    font-size: 130%;
}
.fc .fc-today-button {
    background-image: none;
}
.filter-container button {
    background-color: #fff;
    border: 1px solid #ccc;
    border-radius: 0 3px 3px 0;
}
.image-rows-container {
    background-color: rgba(10, 80, 123, 0.15);
    border: 0 none;
    border-radius: 4px;
}
aside .nav > li > a {
    border-top: 1px solid #ebe9e9;
    padding: 15px;
}
aside .nav > li > a:active,
aside .nav > li > a:focus,
aside .nav > li > a:hover,
aside .nav > li > a.active {
    background-color: rgba(10, 80, 123, 0.2);
}
aside .nav > li > a .fa {
    font-size: 120%;
    margin-right: 5px;
}
.navbar .icon-bar {
    background-color: #5a6169;
}
.navbar-brand {
    padding-left: 0;
}
.navbar-header img {
    height: 30px;
    margin-top: 0;
}
.navbar-toggle .icon-bar {
    height: 1px;
    width: 14px;
}
.navbar-top-links li a:hover {
    background-color: #f5f6f8;
    text-decoration: none;
}
.navbar-top-links .dropdown-menu li a {
    display: block;
    padding: 3px 15px;
}
.navbar-top-links .dropdown-menu li a .fa {
    color: #cacedb;
    margin-right: 5px;
}
.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
    background-color: #eee;
    border-color: #ddd;
    color: #5a6169;
}
.paginator.paginator-admin {
    margin-bottom: 30px;
    padding: 20px;
}
.paginator-actions.pull-right > .btn {
    font-size: 90%;
    margin-left: 5px;
    margin-top: 5px;
    padding: 5px 12px;
}
.panel {
    margin-bottom: 20px;
}
.panel .panel-heading {
    border-radius: 4px 4px 0 0;
}
.panel.panel-default .panel-heading {
    background-color: transparent;
    border-color: #e1e5eb;
    font-size: 120%;
    font-weight: 500;
    padding: 15px 20px;
}
.panel.panel-default .panel-heading .fa {
    background-color: rgba(10, 80, 123, 0.25);
    border-radius: 50%;
    color: #0a507b;
    font-size: 90%;
    height: 33px;
    line-height: 33px;
    margin-right: 5px;
    text-align: center;
    vertical-align: 0;
    width: 33px;
}
.panel.panel-fullscreen {
    background-color: #fff;
    padding: 40px;
}
.panel.notification-panel .panel-body > a:hover {
    color: #30343f;
    text-decoration: none;
}
.panel.notification-panel .panel-body span:first-child {
    font-size: 900%;
}
.panel .table > thead > tr > th {
    border-radius: 0 !important;
}
main .padding-md {
    padding: 0 30px;
}
.shortcut-wrapper {
    border: 0 none;
    align-items: stretch;
    margin-bottom: 0;
    margin-left: -10px;
    margin-right: -10px;
}
.shortcut-wrapper .shortcut-link {
    background-color: rgba(10, 80, 123, 0.75);
    border-radius: 4px;
    color: #fff;
    flex-grow: 1;
    flex-shrink: 1;
    margin: 0 10px 20px;
    padding: 20px;
}
.shortcut-wrapper .shortcut-link:hover {
    background-color: rgba(10, 80, 123, 0.85);
}
.shortcut-wrapper .shortcut-link .shortcut-icon {
    background-color: rgba(255, 255, 255, 0.25);
    border-radius: 50%;
    color: #0a507b;
    font-size: 90%;
    height: 33px;
    line-height: 33px;
    float: left;
    font-size: 120%;
    margin-right: 10px;
    width: 33px;
}
.shortcut-wrapper .shortcut-description {
    text-align: left;
}
.sidebar {
    margin-left: 20px;
    width: 230px;
}
.sidebar .nav-second-level li a {
    padding-bottom: 7px;
    padding-left: 45px;
    padding-top: 7px;
}
.table>thead>tr>th,
.table>tbody>tr>th,
.table>tfoot>tr>th,
.table>thead>tr>td,
.table>tbody>tr>td,
.table>tfoot>tr>td {
    padding: 10px 20px;
}
.table > thead > tr > th {
    background-color: rgba(10, 80, 123, 0.05);
    border-bottom: 1px solid #ebe9e9;
}
.table > thead > tr > th:first-child {
    border-radius: 4px 0 0 0;
}
.table > thead > tr > th:last-child {
    border-radius: 0 4px 0 0;
}

/* Pagination */
.pagination > li > a,
.pagination > li > span {
    border: 0 none;
}
.pagination>li>a:hover,
.pagination>li>span:hover,
.pagination>li>a:focus,
.pagination>li>span:focus {
    background-color: rgba(10, 80, 123, 0.1);
    border-radius: 50%;
}
.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
    background-color: rgba(10, 80, 123, 0.3);
    border-radius: 50%;
}