# Generated by Django 2.1.7 on 2019-04-14 10:49

from django.db import migrations
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0013_auto_20190326_2256'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='scope',
            field=djangoplus.db.models.fields.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='admin.Scope', verbose_name='Scope'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='icon',
            field=djangoplus.db.models.fields.ImageField(blank=True, default=None, null=True, upload_to='config', verbose_name='Ícone'),
        ),
    ]
