{% extends "admin.html" %}

{% block content %}

    {% if widget_panel %}{{ widget_panel|safe }}{% endif %}

    {% if form or panel or paginator %}
    <div class="padding-md">
        {% if form %}{{ form|safe }}{% endif %}
        {% if panel %}{{ panel|safe }}{% endif %}
        {% if paginator %}{{ paginator|safe }}{% endif %}
    </div>
    {% endif %}

{% endblock %}
