{% extends "login/base.html" %}


{% block form %}


                        <form id="login-form" method="POST" action="{{ request.path }}" class="ajax-form" novalidate>
                            {% csrf_token %}

                            <div class="form-group">
                                <label>{{ _("Password") }}</label>
                                <input type="password" id="id_new_password" name="new_password" placeholder="Senha" class="form-control input-sm bounceIn animation-delay4">
                                {{ form.new_password.errors }}
                            </div>

                            <div class="form-group">
                                <label>{{ _("Confirm Password") }}</label>
                                <input type="password" id="id_confirm_password" name="confirm_password" placeholder="Confirmação" class="form-control input-sm bounceIn animation-delay4">
                                {{ form.confirm_password.errors }}
                            </div>

                            <div class="seperator"></div>
                            <hr/>

                            <button class="btn btn-default btn-md bounceIn animation-delay5 pull-right" type="submit"><i class="fa fa-sign-in"></i> {{ _("Save") }}</button>

                        </form>

{% endblock %}